@@ -5,6 +5,7 @@ extern "C" {
 #endif
 
 #include "Python.h"
+#include "Mys-pyarena.h"
 
 #ifndef Py_LIMITED_API
 PyAPI_FUNC(struct _mod *) Mys_PyParser_ASTFromString(
@@ -12,13 +13,13 @@ PyAPI_FUNC(struct _mod *) Mys_PyParser_ASTFromString(
     const char *filename,
     int mode,
     PyCompilerFlags *flags,
-    PyArena *arena);
+    Mys_PyArena *arena);
 PyAPI_FUNC(struct _mod *) Mys_PyParser_ASTFromStringObject(
     const char *str,
     PyObject* filename,
     int mode,
     PyCompilerFlags *flags,
-    PyArena *arena);
+    Mys_PyArena *arena);
 PyAPI_FUNC(struct _mod *) Mys_PyParser_ASTFromFile(
     FILE *fp,
     const char *filename,
@@ -28,7 +29,7 @@ PyAPI_FUNC(struct _mod *) Mys_PyParser_ASTFromFile(
     const char *ps2,
     PyCompilerFlags *flags,
     int *errcode,
-    PyArena *arena);
+    Mys_PyArena *arena);
 PyAPI_FUNC(struct _mod *) Mys_PyParser_ASTFromFileObject(
     FILE *fp,
     PyObject *filename_ob,
@@ -38,12 +39,12 @@ PyAPI_FUNC(struct _mod *) Mys_PyParser_ASTFromFileObject(
     const char *ps2,
     PyCompilerFlags *flags,
     int *errcode,
-    PyArena *arena);
+    Mys_PyArena *arena);
 PyAPI_FUNC(struct _mod *) Mys_PyParser_ASTFromFilename(
     const char *filename,
     int mode,
     PyCompilerFlags *flags,
-    PyArena *arena);
+    Mys_PyArena *arena);
 #endif /* !Py_LIMITED_API */
 
 #ifdef __cplusplus
