@@ -1,6 +1,8 @@
 from collections import defaultdict
 
 from .utils import CompileError
+from .utils import Optional
+from .utils import Weak
 from .utils import is_primitive_type
 from .utils import is_snake_case
 from .utils import split_dict_mys_type
@@ -107,6 +109,8 @@ class Context:
         self.method_comprehensions = defaultdict(list)
         self.traceback = Traceback(source_lines)
         self.package = module_levels[0]
+        self.is_macro = False
+        self.macros = []
 
     def unique_number(self):
         self.unique_count += 1
@@ -191,6 +195,9 @@ class Context:
 
         return self._classes[full_name]
 
+    def does_class_implement_trait(self, class_name, trait_name):
+        return trait_name in self.get_class_definitions(class_name).implements
+
     def define_trait(self, name, full_name, definitions):
         self._name_to_full_name[name] = full_name
         self._traits[full_name] = definitions
@@ -214,16 +221,10 @@ class Context:
         return self._traits[full_name]
 
     def define_function(self, name, full_name, definitions):
-        if all(definition.is_test for definition in definitions):
-            return
-
         self._name_to_full_name[name] = full_name
         self._functions[full_name] = []
 
         for definition in definitions:
-            if definition.is_test:
-                continue
-
             self._functions[full_name].append(definition)
 
     def is_function_defined(self, full_name):
@@ -290,6 +291,10 @@ class Context:
             for item_mys_type in mys_type:
                 if not self.is_type_defined(item_mys_type):
                     return False
+        elif isinstance(mys_type, Optional):
+            return self.is_type_defined(mys_type.mys_type)
+        elif isinstance(mys_type, Weak):
+            return self.is_type_defined(mys_type.mys_type)
         elif self.is_class_or_trait_defined(mys_type):
             return True
         elif self.is_enum_defined(mys_type):
