@@ -6,6 +6,8 @@ from .utils import INTEGER_TYPES
 from .utils import METHOD_BIN_OPERATORS
 from .utils import CompileError
 from .utils import GenericType
+from .utils import Optional
+from .utils import Weak
 from .utils import format_mys_type
 from .utils import get_import_from_info
 from .utils import has_docstring
@@ -15,6 +17,15 @@ from .utils import is_upper_snake_case
 from .utils import make_function_name
 
 
+def is_test(node):
+    for decorator in node.decorator_list:
+        if isinstance(decorator, ast.Name):
+            if decorator.id == 'test':
+                return True
+
+    return False
+
+
 class TypeVisitor(ast.NodeVisitor):
 
     def visit_Name(self, node):
@@ -44,14 +55,21 @@ class TypeVisitor(ast.NodeVisitor):
 
     def visit_Subscript(self, node):
         value = self.visit(node.value)
-        types = self.visit(node.slice)
 
-        if isinstance(node.slice, ast.Name):
-            types = [types]
+        if value == 'optional':
+            return Optional(self.visit(node.slice), node)
+        elif value == 'weak':
+            return Weak(self.visit(node.slice), node)
         else:
-            types = list(types)
+            types = self.visit(node.slice)
 
-        return GenericType(value, types, node)
+            if (isinstance(node.slice, ast.Name)
+                or isinstance(types, (Optional, Weak))):
+                types = [types]
+            else:
+                types = list(types)
+
+            return GenericType(value, types, node)
 
 
 class FormatDefaultVisitor(ast.NodeVisitor):
@@ -105,7 +123,6 @@ class Function:
                  name,
                  generic_types,
                  raises,
-                 is_test,
                  is_macro,
                  args,
                  returns,
@@ -116,7 +133,6 @@ class Function:
         self.name = name
         self.generic_types = generic_types
         self.raises = raises
-        self.is_test = is_test
         self.is_macro = is_macro
         self.args = args
         self.returns = returns
@@ -182,6 +198,18 @@ class Function:
             f'args={args}, returns={self.returns}, module_name={self.module_name}, '
             f'is_overloaded={self.is_overloaded})')
 
+
+class Test:
+
+    def __init__(self, name, node, docstring=None):
+        self.name = name
+        self.node = node
+        self.docstring = docstring
+
+    def __str__(self):
+        return f'Test(name={self.name})'
+
+
 class Param:
 
     def __init__(self, name, type_, node):
@@ -192,6 +220,7 @@ class Param:
     def __str__(self):
         return f'Param(name={self.name}, type={self.type})'
 
+
 class Member:
 
     def __init__(self, name, type_, node):
@@ -304,6 +333,7 @@ class Definitions:
         self.enums = {}
         self.functions = defaultdict(list)
         self.imports = defaultdict(list)
+        self.tests = {}
 
     def _check_unique_name(self, name, node, is_function=False):
         if name in self.variables:
@@ -345,15 +375,17 @@ class Definitions:
         value.module_name = self.module_name
         functions = self.functions[name]
 
-        if functions and not value.is_test:
-            if any(not function.is_test for function in functions):
-                value.is_overloaded = True
+        if functions:
+            value.is_overloaded = True
 
-                for function in functions:
-                    function.is_overloaded = True
+            for function in functions:
+                function.is_overloaded = True
 
         functions.append(value)
 
+    def define_test(self, name, value):
+        self.tests[name] = value
+
     def add_import(self, module, name, asname):
         self.imports[asname].append((module, name))
 
@@ -422,7 +454,7 @@ def is_method(node):
 
 class FunctionVisitor(TypeVisitor):
 
-    ALLOWED_DECORATORS = ['generic', 'test', 'raises', 'macro']
+    ALLOWED_DECORATORS = ['generic', 'raises', 'macro']
 
     def visit_arg(self, node):
         if node.annotation is None:
@@ -474,7 +506,6 @@ class FunctionVisitor(TypeVisitor):
         return Function(node.name,
                         decorators.get('generic', []),
                         decorators.get('raises', []),
-                        'test' in decorators,
                         is_macro,
                         args,
                         returns,
@@ -484,6 +515,29 @@ class FunctionVisitor(TypeVisitor):
                         docstring)
 
 
+class TestVisitor(TypeVisitor):
+
+    def visit_FunctionDef(self, node):
+        if len(node.decorator_list) != 1:
+            raise CompileError('tests cannot have decorators', node)
+
+        if len(node.args.args) != 0:
+            raise CompileError('tests cannot have parameters', node)
+
+        if node.returns is not None:
+            raise CompileError('tests cannot return any value', node)
+
+        if not is_snake_case(node.name):
+            raise CompileError("test names must be snake case", node)
+
+        if has_docstring(node):
+            docstring = node.body[0].value.value
+        else:
+            docstring = None
+
+        return Test(node.name, node, docstring)
+
+
 class MethodVisitor(FunctionVisitor):
 
     ALLOWED_DECORATORS = ['generic', 'raises', 'macro']
@@ -840,10 +894,12 @@ class DefinitionsVisitor(ast.NodeVisitor):
             self.visit_class(node, decorators)
 
     def visit_FunctionDef(self, node):
-        self._definitions.define_function(node.name,
-                                          FunctionVisitor().visit(node),
-                                          node)
-
+        if is_test(node):
+            self._definitions.define_test(node.name, TestVisitor().visit(node))
+        else:
+            self._definitions.define_function(node.name,
+                                              FunctionVisitor().visit(node),
+                                              node)
 
 def find_definitions(tree, source_lines, module_levels, module_name):
     """Find all definitions in given tree and return them.
@@ -882,6 +938,12 @@ class MakeFullyQualifiedNames:
 
             mys_type.types = types
 
+            return mys_type
+        elif isinstance(mys_type, Optional):
+            return self.process_type(mys_type.mys_type)
+        elif isinstance(mys_type, Weak):
+            mys_type.mys_type = self.process_type(mys_type.mys_type)
+
             return mys_type
         elif mys_type in self.module_definitions.classes:
             return f'{self.module}.{mys_type}'
