@@ -101,7 +101,6 @@ def specialize_function(function, specialized_full_name, chosen_types, node):
     return Function(specialized_full_name,
                     [],
                     function.raises,
-                    function.is_test,
                     function.is_macro,
                     args,
                     returns,
@@ -287,4 +286,7 @@ class TypeVisitor(ast.NodeVisitor):
         return {self.visit(node.elts[0])}
 
     def visit_Subscript(self, node):
-        return add_generic_class(node, self.context)[1]
+        if self.visit(node.value) == 'optional':
+            return self.visit(node.slice)
+        else:
+            return add_generic_class(node, self.context)[1]
