@@ -15,6 +15,29 @@ class GenericType:
         return f'GenericType(name={self.name}, types={self.types})'
 
 
+class Optional:
+
+    def __init__(self, mys_type, node):
+        self.mys_type = mys_type
+        self.node = node
+
+    def __eq__(self, other):
+        return isinstance(other, Optional) and self.mys_type == other.mys_type
+
+
+class Weak:
+
+    def __init__(self, mys_type, node):
+        self.mys_type = mys_type
+        self.node = node
+
+    def __eq__(self, other):
+        if isinstance(other, Weak):
+            return self.mys_type == other.mys_type
+        else:
+            return self.mys_type == other
+
+
 class CompileError(Exception):
 
     def __init__(self, message, node):
@@ -267,6 +290,13 @@ def is_primitive_type(mys_type):
     return mys_type in PRIMITIVE_TYPES
 
 
+def is_builtin_type(mys_type):
+    if not isinstance(mys_type, str):
+        return False
+
+    return mys_type in BUILTIN_TYPES
+
+
 def is_integer_type(mys_type):
     if not isinstance(mys_type, str):
         return False
@@ -349,8 +379,11 @@ def make_shared(cpp_type, values):
     return f'mys::make_shared<{cpp_type}>({values})'
 
 
-def shared_list_type(cpp_type):
-    return f'SharedList<{cpp_type}>'
+def shared_list_type(cpp_type, is_weak=False):
+    if is_weak:
+        return f'mys::weak_ptr<mys::List<{cpp_type}>>'
+    else:
+        return f'mys::shared_ptr<mys::List<{cpp_type}>>'
 
 
 def make_shared_list(cpp_type, value):
@@ -363,8 +396,11 @@ def make_shared_set(cpp_type, value):
             f'std::initializer_list<{cpp_type}>{{{value}}})')
 
 
-def shared_dict_type(key_cpp_type, value_cpp_type):
-    return f'SharedDict<{key_cpp_type}, {value_cpp_type}>'
+def shared_dict_type(key_cpp_type, value_cpp_type, is_weak=False):
+    if is_weak:
+        return f'mys::weak_ptr<mys::Dict<{key_cpp_type}, {value_cpp_type}>>'
+    else:
+        return f'mys::shared_ptr<mys::Dict<{key_cpp_type}, {value_cpp_type}>>'
 
 
 def make_shared_dict(key_cpp_type, value_cpp_type, items):
@@ -373,32 +409,45 @@ def make_shared_dict(key_cpp_type, value_cpp_type, items):
             f'{value_cpp_type}>>{{{items}}})')
 
 
-def shared_set_type(cpp_type):
-    return f'SharedSet<{cpp_type}>'
+def shared_set_type(cpp_type, is_weak=False):
+    if is_weak:
+        return f'mys::weak_ptr<mys::Set<{cpp_type}>>'
+    else:
+        return f'mys::shared_ptr<mys::Set<{cpp_type}>>'
 
 
-def shared_tuple_type(items):
-    return f'SharedTuple<{items}>'
+def shared_tuple_type(items, is_weak=False):
+    if is_weak:
+        return f'mys::weak_ptr<mys::Tuple<{items}>>'
+    else:
+        return f'mys::shared_ptr<mys::Tuple<{items}>>'
 
 
 def mys_to_cpp_type(mys_type, context):
+    if isinstance(mys_type, Weak):
+        is_weak = True
+        mys_type = mys_type.mys_type
+    else:
+        is_weak = False
+
     if isinstance(mys_type, tuple):
         items = ', '.join([mys_to_cpp_type(item, context) for item in mys_type])
 
-        return shared_tuple_type(items)
+        return shared_tuple_type(items, is_weak)
     elif isinstance(mys_type, list):
         item = mys_to_cpp_type(mys_type[0], context)
 
-        return shared_list_type(item)
+        return shared_list_type(item, is_weak)
     elif isinstance(mys_type, dict):
         key_mys_type, value_mys_type = split_dict_mys_type(mys_type)
         key = mys_to_cpp_type(key_mys_type, context)
         value = mys_to_cpp_type(value_mys_type, context)
 
-        return shared_dict_type(key, value)
+        return shared_dict_type(key, value, is_weak)
     elif isinstance(mys_type, set):
         item = mys_to_cpp_type(list(mys_type)[0], context)
-        return shared_set_type(item)
+
+        return shared_set_type(item, is_weak)
     else:
         if mys_type == 'string':
             return 'mys::String'
@@ -413,7 +462,10 @@ def mys_to_cpp_type(mys_type, context):
         elif mys_type == 'regexmatch':
             return 'mys::RegexMatch'
         elif context.is_class_or_trait_defined(mys_type):
-            return f'mys::shared_ptr<{dot2ns(mys_type)}>'
+            if is_weak:
+                return f'mys::weak_ptr<{dot2ns(mys_type)}>'
+            else:
+                return f'mys::shared_ptr<{dot2ns(mys_type)}>'
         elif context.is_enum_defined(mys_type):
             return context.get_enum_type(mys_type)
         else:
@@ -571,6 +623,13 @@ class MakeIntegerLiteralVisitor(ast.NodeVisitor):
                 return '(-0x7fffffffffffffff - 1)'
         elif self.type_name is None:
             raise CompileError("integers cannot be None", node)
+        elif isinstance(self.type_name, Optional):
+            type_name = self.type_name
+            self.type_name = type_name.mys_type
+            value = self.visit_Constant(node)
+            self.type_name = type_name
+
+            return value
         else:
             mys_type = format_mys_type(self.type_name)
 
@@ -658,6 +717,8 @@ def format_mys_type(mys_type):
         types = ', '.join(format_mys_type(type) for type in mys_type.types)
 
         return f'{mys_type.name}[{types}]'
+    elif isinstance(mys_type, Optional):
+        return f'{format_mys_type(mys_type.mys_type)}?'
     else:
         return str(mys_type)
 
