@@ -11,7 +11,7 @@ class Test(TestCase):
         self.assert_transpile_raises(
             'class Foo:\n'
             '    pass\n'
-            'def foo() -> [(string, Foo)]:\n'
+            'func foo() -> [(string, Foo)]:\n'
             '    return {1: 2}',
             '  File "", line 4\n'
             '        return {1: 2}\n'
@@ -20,7 +20,7 @@ class Test(TestCase):
 
     def test_wrong_dict_key_type(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v = {1: 5}\n'
             '    v["a"] = 4\n',
             '  File "", line 3\n'
@@ -30,7 +30,7 @@ class Test(TestCase):
 
     def test_bad_dict_key_type(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v: {Foo: bool} = None\n',
             # Should probably say that Foo is not defined.
             '  File "", line 2\n'
@@ -40,7 +40,7 @@ class Test(TestCase):
 
     def test_dict_value_type_not_defined(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v: {bool: Foo} = None\n',
             # Should probably say that Foo is not defined.
             '  File "", line 2\n'
@@ -50,7 +50,7 @@ class Test(TestCase):
 
     def test_wrong_dict_value_type(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v = {1: 5}\n'
             '    v[2] = 2.5\n',
             '  File "", line 3\n'
@@ -60,7 +60,7 @@ class Test(TestCase):
 
     def test_dict_init_key_types_mismatch_1(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v: {i64: i64} = {1: 5, True: 0}\n'
             '    print(v)\n',
             '  File "", line 2\n'
@@ -70,7 +70,7 @@ class Test(TestCase):
 
     def test_dict_init_key_types_mismatch_2(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v = {True: 5, 1: 4}\n'
             '    print(v)\n',
             '  File "", line 2\n'
@@ -80,7 +80,7 @@ class Test(TestCase):
 
     def test_dict_init_value_types_mismatch_1(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v: {bool: i64} = {True: 5, False: "a"}\n'
             '    print(v)\n',
             '  File "", line 2\n'
@@ -90,7 +90,7 @@ class Test(TestCase):
 
     def test_dict_init_value_types_mismatch_2(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v = {True: i8(5), False: u8(4)}\n'
             '    print(v)\n',
             '  File "", line 2\n'
@@ -100,7 +100,7 @@ class Test(TestCase):
 
     def test_only_iterate_over_dict_pairs_supported(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    for item in {1: 2}:\n'
             '        print(item)\n',
             '  File "", line 2\n'
