@@ -12,7 +12,7 @@ class Test(TestCase):
         self.assert_transpile_raises(
             'class Foo:\n'
             '    x: i32\n'
-            'def foo(v: Foo):\n'
+            'func foo(v: Foo):\n'
             '    match v:\n'
             '        case Foo(x=1):\n'
             '            pass\n',
@@ -23,7 +23,7 @@ class Test(TestCase):
 
     def test_match_wrong_case_type(self):
         self.assert_transpile_raises(
-            'def foo(v: i32):\n'
+            'func foo(v: i32):\n'
             '    match v:\n'
             '        case 1:\n'
             '            pass\n'
@@ -36,7 +36,7 @@ class Test(TestCase):
 
     def test_match_pattern_condition(self):
         self.assert_transpile_raises(
-            'def foo(x: i32, y: u8):\n'
+            'func foo(x: i32, y: u8):\n'
             '    match x:\n'
             '        case 1 if y == 2:\n'
             '            pass\n',
@@ -47,88 +47,83 @@ class Test(TestCase):
 
     def test_match_trait_pattern_condition(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
+            'trait Base:\n'
             '    pass\n'
             'class Foo(Base):\n'
             '    pass\n'
-            'def foo(base: Base):\n'
+            'func foo(base: Base):\n'
             '    match base:\n'
             '        case Foo() if False:\n'
             '            print("foo")\n',
-            '  File "", line 8\n'
+            '  File "", line 7\n'
             '            case Foo() if False:\n'
             '                          ^\n'
             "CompileError: guards are not supported\n")
 
     def test_match_trait_pattern_not_class_1(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
+            'trait Base:\n'
             '    pass\n'
             'class Foo(Base):\n'
             '    pass\n'
-            'def foo(base: Base):\n'
+            'func foo(base: Base):\n'
             '    match base:\n'
             '        case Foo as e:\n'
             '            print(e)\n',
-            '  File "", line 8\n'
+            '  File "", line 7\n'
             '            case Foo as e:\n'
             '                 ^\n'
             "CompileError: trait match patterns must be class objects\n")
 
     def test_match_trait_pattern_not_class_2(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
+            'trait Base:\n'
             '    pass\n'
             'class Foo(Base):\n'
             '    pass\n'
-            'def foo(base: Base):\n'
+            'func foo(base: Base):\n'
             '    match base:\n'
             '        case Foo:\n'
             '            pass\n',
-            '  File "", line 8\n'
+            '  File "", line 7\n'
             '            case Foo:\n'
             '                 ^\n'
             "CompileError: trait match patterns must be class objects\n")
 
     def test_match_trait_pattern_with_arg(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
+            'trait Base:\n'
             '    pass\n'
             'class Foo(Base):\n'
             '    x: i64\n'
-            'def foo(base: Base):\n'
+            'func foo(base: Base):\n'
             '    match base:\n'
             '        case Foo(5):\n'
             '            pass\n',
-            '  File "", line 8\n'
+            '  File "", line 7\n'
             '            case Foo(5):\n'
             '                 ^\n'
             "CompileError: only keyword arguments can be matched\n")
 
     def test_match_trait_pattern_with_non_constant_arg(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
+            'trait Base:\n'
             '    pass\n'
             'class Foo(Base):\n'
             '    x: i64\n'
-            'def foo(base: Base):\n'
+            'func foo(base: Base):\n'
             '    v: i64 = 5\n'
             '    match base:\n'
             '        case Foo(x=v):\n'
             '            pass\n',
-            '  File "", line 9\n'
+            '  File "", line 8\n'
             '            case Foo(x=v):\n'
             '                 ^\n'
             "CompileError: only constants can be matched\n")
 
     def test_bare_integer_in_match_case(self):
         self.assert_transpile_raises(
-            'def foo(a: u8):\n'
+            'func foo(a: u8):\n'
             '    match a:\n'
             '        case 1:\n'
             '            1\n',
