@@ -13,8 +13,7 @@ class Test(TestCase):
         build_and_test_module('traits')
 
     def test_define_empty_trait(self):
-        header = transpile_early_header('@trait\n'
-                                        'class Foo:\n'
+        header = transpile_early_header('trait Foo:\n'
                                         '    pass\n')
         self.assert_in('class Foo : public mys::Object {\n'
                        'public:\n'
@@ -24,34 +23,21 @@ class Test(TestCase):
 
     def test_define_trait_with_member(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Foo:\n'
+            'trait Foo:\n'
             '    a: i32\n',
-            '  File "", line 3\n'
+            '  File "", line 2\n'
             '        a: i32\n'
             '        ^\n'
             "CompileError: traits cannot have members\n")
 
-    def test_define_trait_with_parameter(self):
-        self.assert_transpile_raises(
-            '@trait(u32)\n'
-            'class Foo:\n'
-            '    pass\n',
-            '  File "", line 1\n'
-            '    @trait(u32)\n'
-            '     ^\n'
-            "CompileError: no parameters expected\n")
-
     def test_define_trait_with_same_name_twice(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Foo:\n'
+            'trait Foo:\n'
             '    pass\n'
-            '@trait\n'
-            'class Foo:\n'
+            'trait Foo:\n'
             '    pass\n',
-            '  File "", line 5\n'
-            '    class Foo:\n'
+            '  File "", line 3\n'
+            '    trait Foo:\n'
             '    ^\n'
             "CompileError: there is already a trait called 'Foo'\n")
 
@@ -59,11 +45,10 @@ class Test(TestCase):
         self.assert_transpile_raises(
             'class Foo:\n'
             '    pass\n'
-            '@trait\n'
-            'class Foo:\n'
+            'trait Foo:\n'
             '    pass\n',
-            '  File "", line 4\n'
-            '    class Foo:\n'
+            '  File "", line 3\n'
+            '    trait Foo:\n'
             '    ^\n'
             "CompileError: there is already a class called 'Foo'\n")
 
@@ -78,19 +63,17 @@ class Test(TestCase):
 
     def test_wrong_function_parameter_type_trait(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
+            'trait Base:\n'
             '    pass\n'
-            '@trait\n'
-            'class WrongBase:\n'
+            'trait WrongBase:\n'
             '    pass\n'
             'class Foo(Base):\n'
             '    pass\n'
-            'def foo(a: WrongBase):\n'
+            'func foo(a: WrongBase):\n'
             '    pass\n'
-            'def bar():\n'
+            'func bar():\n'
             '    foo(Foo())\n',
-            '  File "", line 12\n'
+            '  File "", line 10\n'
             '        foo(Foo())\n'
             '            ^\n'
             "CompileError: 'foo.lib.Foo' does not implement trait "
@@ -98,76 +81,70 @@ class Test(TestCase):
 
     def test_trait_init(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Foo:\n'
-            '    def __init__(self):\n'
+            'trait Foo:\n'
+            '    func __init__(self):\n'
             '        pass\n',
-            '  File "", line 3\n'
-            '        def __init__(self):\n'
+            '  File "", line 2\n'
+            '        func __init__(self):\n'
             '        ^\n'
             "CompileError: traits cannot have an __init__ method\n")
 
     def test_pure_trait_method_not_implemented_pass(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
-            '    def foo(self):\n'
+            'trait Base:\n'
+            '    func foo(self):\n'
             '        pass\n'
             'class Foo(Base):\n'
             '    pass\n',
-            '  File "", line 5\n'
+            '  File "", line 4\n'
             '    class Foo(Base):\n'
             '              ^\n'
             "CompileError: pure trait method 'foo' is not implemented\n")
 
     def test_pure_trait_method_not_implemented_many_pass(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
-            '    def foo(self):\n'
+            'trait Base:\n'
+            '    func foo(self):\n'
             '        pass\n'
             '        pass\n'
             '        pass\n'
             'class Foo(Base):\n'
             '    pass\n',
-            '  File "", line 7\n'
-            '    class Foo(Base):\n'
-            '              ^\n'
-            "CompileError: pure trait method 'foo' is not implemented\n")
-
-    def test_pure_trait_method_not_implemented_docstring(self):
-        self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
-            '    def foo(self):\n'
-            '        "Doc"\n'
-            'class Foo(Base):\n'
-            '    pass\n',
-            '  File "", line 5\n'
-            '    class Foo(Base):\n'
-            '              ^\n'
-            "CompileError: pure trait method 'foo' is not implemented\n")
-
-    def test_pure_trait_method_not_implemented_docstring_and_pass(self):
-        self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
-            '    def foo(self):\n'
-            '        "Doc"\n'
-            '        pass\n'
-            'class Foo(Base):\n'
-            '    pass\n',
             '  File "", line 6\n'
             '    class Foo(Base):\n'
             '              ^\n'
             "CompileError: pure trait method 'foo' is not implemented\n")
 
+    def test_pure_trait_method_not_implemented_docstring(self):
+        self.assert_transpile_raises(
+            'trait Base:\n'
+            '    func foo(self):\n'
+            '        "Doc"\n'
+            'class Foo(Base):\n'
+            '    pass\n',
+            '  File "", line 4\n'
+            '    class Foo(Base):\n'
+            '              ^\n'
+            "CompileError: pure trait method 'foo' is not implemented\n")
+
+    def test_pure_trait_method_not_implemented_docstring_and_pass(self):
+        self.assert_transpile_raises(
+            'trait Base:\n'
+            '    func foo(self):\n'
+            '        "Doc"\n'
+            '        pass\n'
+            'class Foo(Base):\n'
+            '    pass\n',
+            '  File "", line 5\n'
+            '    class Foo(Base):\n'
+            '              ^\n'
+            "CompileError: pure trait method 'foo' is not implemented\n")
+
     def test_imported_pure_trait_method_not_implemented(self):
         with self.assertRaises(TranspilerError) as cm:
             transpile([
-                Source('@trait\n'
-                       'class Base:\n'
-                       '    def foo(self):\n'
+                Source('trait Base:\n'
+                       '    func foo(self):\n'
                        '        pass\n',
                        module='foo.lib'),
                 Source('from foo import Base\n'
@@ -184,12 +161,11 @@ class Test(TestCase):
 
     def test_trait_member_access_1(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Base:\n'
+            'trait Base:\n'
             '    pass\n'
-            'def foo(v: Base):\n'
+            'func foo(v: Base):\n'
             '    v.a = 1\n',
-            '  File "", line 5\n'
+            '  File "", line 4\n'
             '        v.a = 1\n'
             '        ^\n'
             "CompileError: 'foo.lib.Base' has no member 'a'\n")
@@ -197,9 +173,9 @@ class Test(TestCase):
     def test_trait_member_access_2(self):
         self.assert_transpile_raises(
             'class Foo:\n'
-            '    def foo(self, v: bool):\n'
+            '    func foo(self, v: bool):\n'
             '        pass\n'
-            'def foo(v: Foo):\n'
+            'func foo(v: Foo):\n'
             '    v.foo()\n',
             '  File "", line 5\n'
             '        v.foo()\n'
@@ -208,33 +184,30 @@ class Test(TestCase):
 
     def test_wrong_trait_method_parameter_type(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Foo:\n'
-            '    def foo(self, v: bool):\n'
+            'trait Foo:\n'
+            '    func foo(self, v: bool):\n'
             '        pass\n'
-            'def foo(v: Foo):\n'
+            'func foo(v: Foo):\n'
             '    v.foo(b"")\n',
-            '  File "", line 6\n'
+            '  File "", line 5\n'
             '        v.foo(b"")\n'
             '              ^\n'
             "CompileError: expected a 'bool', got a 'bytes'\n")
 
     def test_trait_pascal_case(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class foo:\n'
+            'trait foo:\n'
             '    pass\n',
-            '  File "", line 2\n'
-            '    class foo:\n'
+            '  File "", line 1\n'
+            '    trait foo:\n'
             '    ^\n'
             "CompileError: trait names must be pascal case\n")
 
     def test_trait_member(self):
         self.assert_transpile_raises(
-            '@trait\n'
-            'class Foo:\n'
+            'trait Foo:\n'
             '    x: i32\n',
-            '  File "", line 3\n'
+            '  File "", line 2\n'
             '        x: i32\n'
             '        ^\n'
             "CompileError: traits cannot have members\n")
